@@ -32,15 +32,15 @@ BASE_LIBRARY_PATH = os.path.join(mpl.get_data_path(), 'stylelib')
 # Users may want multiple library paths, so store a list of paths.
 USER_LIBRARY_PATHS = [os.path.join(mpl._get_configdir(), 'stylelib')]
 STYLE_EXTENSION = 'mplstyle'
-STYLE_FILE_PATTERN = re.compile('([\S]+).%s$' % STYLE_EXTENSION)
+STYLE_FILE_PATTERN = re.compile(r'([\S]+).%s$' % STYLE_EXTENSION)
 
 
 # A list of rcParams that should not be applied from styles
-STYLE_BLACKLIST = set([
+STYLE_BLACKLIST = {
     'interactive', 'backend', 'backend.qt4', 'webagg.port',
     'webagg.port_retries', 'webagg.open_in_browser', 'backend_fallback',
     'toolbar', 'timezone', 'datapath', 'figure.max_open_warning',
-    'savefig.directory', 'tk.window_focus', 'docstring.hardcopy'])
+    'savefig.directory', 'tk.window_focus', 'docstring.hardcopy'}
 
 
 def _remove_blacklisted_style_params(d, warn=True):
@@ -89,14 +89,20 @@ def use(style):
 
 
     """
-    if cbook.is_string_like(style) or hasattr(style, 'keys'):
+    style_alias = {'mpl20': 'default',
+                   'mpl15': 'classic'}
+    if isinstance(style, six.string_types) or hasattr(style, 'keys'):
         # If name is a single str or dict, make it a single element list.
         styles = [style]
     else:
         styles = style
 
+    styles = (style_alias.get(s, s)
+              if isinstance(s, six.string_types)
+              else s
+              for s in styles)
     for style in styles:
-        if not cbook.is_string_like(style):
+        if not isinstance(style, six.string_types):
             _apply_style(style)
         elif style == 'default':
             _apply_style(rcParamsDefault, warn=False)
@@ -225,7 +231,6 @@ available = []
 
 def reload_library():
     """Reload style library."""
-    global library, available
-    library = update_user_library(_base_library)
-    available[:] = library.keys()
+    global library
+    available[:] = library = update_user_library(_base_library)
 reload_library()
